//***************************************************
// C++ document adapter for Winmeta plugins
//
// Requires: WINMETA.DLL version 1.0
// (WINMETA.DLL is  2007 Peter Koller, Maison Anglais. All Rights Reserved)
//
// Copyright (C) 2007-2008 Heiko Nitzsche
//
//   This software is provided 'as-is', without any express or implied
//   warranty.  In no event will the author be held liable for any damages
//   arising from the use of this software.
//
//   Permission is granted to anyone to use this software for any purpose,
//   including commercial applications, and to alter it and redistribute it
//   freely, subject to the following restrictions:
//
//   1. The origin of this software must not be misrepresented; you must not
//      claim that you wrote the original software. If you use this software
//      in a product, an acknowledgment in the product documentation would be
//      appreciated but is not required.
//   2. Altered source versions must be plainly marked as such, and must not be
//      misrepresented as being the original software.
//   3. This notice may not be removed or altered from any source distribution.
//
//***************************************************

#ifndef __CLASS_META_ACCESSOR__
    #define __CLASS_META_ACCESSOR__

#include "os2defs.h"
#include "drawwin.h"

// ---------------------------------------------------------

class MetaAccessorException
{
    public:
       MetaAccessorException() {}
      ~MetaAccessorException() {}
};

// ---------------------------------------------------------

class MetaAccessor
{
    private:

        char    * moduleName;
        HMODULE   moduleHandle;

        MetaAccessor(const MetaAccessor & accessor);
        MetaAccessor & operator =(const MetaAccessor & accessor);

        BOOL init(const char * dllPath);

        // --- Function prototype for DLL functions ---

      #if defined(__IBMC__) || defined(__IBMCPP__)

          BOOL  (* APIENTRY fn_IsWinMetafile)(PCHAR metadata, ULONG metasize);
          ULONG (* APIENTRY fn_InitWinMetafile)(HAB hab, HPS hps, PFNWARNPROC warnproc, PVOID warnprocData, ULONG useOpts);
          ULONG (* APIENTRY fn_PaintWinMetafile)(HPS hps, PCHAR metadata, ULONG metasize);
          char* (* APIENTRY fn_FormatMetafileErrorMsg)(char* buffer, ULONG errcode);

      #else

          BOOL  (APIENTRY * fn_IsWinMetafile)(PCHAR metadata, ULONG metasize);
          ULONG (APIENTRY * fn_InitWinMetafile)(HAB hab, HPS hps, PFNWARNPROC warnproc, PVOID warnprocData, ULONG useOpts);
          ULONG (APIENTRY * fn_PaintWinMetafile)(HPS hps, PCHAR metadata, ULONG metasize);
          char* (APIENTRY * fn_FormatMetafileErrorMsg)(char* buffer, ULONG errcode);

      #endif

    // ---------------------------------------------------------

    public:

        MetaAccessor() throw (MetaAccessorException);
        MetaAccessor(const char * dllPath) throw (MetaAccessorException);

        virtual ~MetaAccessor();

        const char * getModuleName() const;

        // WINMETA wrapper functions

        BOOL  IsWinMetafile         (PCHAR metadata, ULONG metasize) const;
        ULONG InitWinMetafile       (HAB hab, HPS hps, PFNWARNPROC warnproc, PVOID warnprocData, ULONG useOpts) const;
        ULONG PaintWinMetafile      (HPS hps, PCHAR metadata, ULONG metasize) const;
        char* FormatMetafileErrorMsg(char* buffer, ULONG errcode) const;
};

#endif


