
//***************************************************
// C++ document adapter for Winmeta plugins
//
// Requires: WINMETA.DLL version 1.0
// (WINMETA.DLL is  2007 Peter Koller, Maison Anglais. All Rights Reserved)
//
// Copyright (C) 2007-2008 Heiko Nitzsche
//
//   This software is provided 'as-is', without any express or implied
//   warranty.  In no event will the author be held liable for any damages
//   arising from the use of this software.
//
//   Permission is granted to anyone to use this software for any purpose,
//   including commercial applications, and to alter it and redistribute it
//   freely, subject to the following restrictions:
//
//   1. The origin of this software must not be misrepresented; you must not
//      claim that you wrote the original software. If you use this software
//      in a product, an acknowledgment in the product documentation would be
//      appreciated but is not required.
//   2. Altered source versions must be plainly marked as such, and must not be
//      misrepresented as being the original software.
//   3. This notice may not be removed or altered from any source distribution.
//
//***************************************************

#ifndef __CLASS_META_DOCUMENT__
    #define __CLASS_META_DOCUMENT__

#include "MetaException.hpp"
#include "MetaAccessor.hpp"
#include "os2defs.h"

// ---------------------------------------------------------

class MetaDocument
{
    private:

        // --- type definitions ---

        enum MetaMode { SETOPTS_PAINT, SETOPTS_GETBOUNDS, SETOPTS_GETSIZE };

        // --- data definitions ---

        const MetaAccessor &  mMetaAccessor;
        char               *  mMetadata;
        ULONG                 mMetadataSize;
        HMF                   mhMetafile;
        int                   mX;
        int                   mY;
        int                   mWidth;
        int                   mHeight;
        const char         *  mFormatDescription;

        // --- functions ---

        MetaDocument();
        MetaDocument(const MetaDocument & doc);
        MetaDocument & operator = ( const MetaDocument & doc );

        void readFile (const char * filename) throw ( MetaException );
        void writeFile(const char * filename) const throw ( MetaException );
        HMF  importOS2Metafile(HAB hab);
        HMF  importWindowsMetafile(HAB hab);
        void calculateMetafileSize(HAB hab);
        void setOpts(PLONG opts, MetaMode mode) const;

    public:

        MetaDocument(const MetaAccessor & accessor);
        virtual ~MetaDocument();

        BOOL hasContent() const;

        void setDocumentFile    (const char * filename) throw ( MetaException );
        void writeDocumentToFile(const char * filename) throw ( MetaException );

        int getWidth();
        int getHeight();

        void renderToHPS(long   src_x    , long   src_y,
                         long   src_width, long   src_height,
                         double scale_x  , double scale_y,
                         long   rotation ,
                         HPS    hps) throw ( MetaException );

        const MetaAccessor & getMetaAccessor();

        const char * getDescription() const;
};

#endif


