# This makefile is for Open Watcom C++ on Windows NT/2000/XP.
# (with JPWL support)

# Location of gbm libs and public header files
GBM   = ..\gbm
IJG   = $(GBM)\libjpeg
OJPEG = $(GBM)\libojpeg
TIFF  = $(GBM)\libtiff
ZLIB  = $(GBM)\zlib

# Installation directory
IDIR = bin

DOCDIR = doc

# ------------------
# Configure compiler
# ------------------

#
# Using Open Watcom C++:
#
CC      = wcc386
CL      = wlink

# Builds gbm objects which are compiled multithreaded
# Therefore all users should also be multithreaded
CWARNS     = -wx -wcd=202 -we
CFLAGS     = $(CWARNS) -i$(GBM) -i$(OJPEG) -i$(TIFF) -bt=nt -zq -zp4 -onatxh -sg -ei -6r -fp5 -bm -mf /DOPJ_STATIC /DUSE_JPWL /DWIN32
CFLAGS_DBG = $(CWARNS) -i$(GBM) -i$(OJPEG) -i$(TIFF) -bt=nt -zq -zp4 -sg -ei -6r -fp5 -bm -mf -d2 /DOPJ_STATIC /DUSE_JPWL /DWIN32 /DDEBUG

LFLAGS     = SYSTEM nt op q op el op stack=0x20000
LFLAGS_DBG = SYSTEM nt op q d all op stack=0x20000

# For debugging call nmake or wmake with debug=on
!ifdef debug
CFLAGS     = $(CFLAGS_DBG)
LFLAGS     = $(LFLAGS_DBG)
!endif

#

.SUFFIXES:	.c .obj

.c.obj:
		$(CC) $(CFLAGS) $*.c

#

all:    image_to_j2k.exe \
        j2k_to_image.exe


# ------------
# Bitmap tools
# ------------

image_to_j2k.exe:	image_to_j2k.obj index.obj convert.obj getopt.obj
		$(CL) $(LFLAGS) name $@ file image_to_j2k.obj,index.obj,convert.obj,getopt.obj library $(OJPEG)\ojpeg.lib,$(TIFF)\tiff.lib,$(IJG)\jpeg.lib,$(ZLIB)\z.lib

j2k_to_image.exe:	j2k_to_image.obj index.obj convert.obj getopt.obj
		$(CL) $(LFLAGS) name $@ file j2k_to_image.obj,index.obj,convert.obj,getopt.obj library $(OJPEG)\ojpeg.lib,$(TIFF)\tiff.lib,$(IJG)\jpeg.lib,$(ZLIB)\z.lib

image_to_j2k.obj:	image_to_j2k.c

j2k_to_image.obj:	j2k_to_image.c

index.obj:	index.c index.h

convert.obj:	convert.c convert.h

getopt.obj: getopt.c getopt.h

# ------------------------
# Build management targets
# ------------------------

clean:
	 -del /F /Q *.obj 2>nul
	 -del /F /Q *.err 2>nul

clobber:
	 -del /F /Q *.obj 2>nul
	 -del /F /Q *.exe 2>nul
	 -del /F /Q *.err 2>nul
	 -del /F /Q $(IDIR)\* 2>nul

#

install:
         copy *.exe $(IDIR)
         copy $(DOCDIR)\readme_j2k.txt $(IDIR)

#

exepack:

#

package:
        -del /F $(IDIR)\j2kcodec.zip 2>nul
        zip -9 $(IDIR)\j2kcodec.zip *.exe $(DOCDIR)\readme_j2k.txt

